@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2013 WebIssues Team
+* Copyright (C) 2007-2014 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -165,7 +165,7 @@ void Application::about()
         " it under the terms of the GNU General Public License as published by"
         " the Free Software Foundation, either version 3 of the License, or"
         " (at your option) any later version." ) + "</p>";
-    message += "<p>" + trUtf8( "Copyright &copy; 2006 Michał Męciński" ) + "<br>" + tr( "Copyright &copy; 2007-2013 WebIssues Team" ) + "</p>";
+    message += "<p>" + trUtf8( "Copyright &copy; 2006 Michał Męciński" ) + "<br>" + tr( "Copyright &copy; 2007-2014 WebIssues Team" ) + "</p>";
 
     QString link = "<a href=\"http://webissues.mimec.org\">webissues.mimec.org</a>";
 
@@ -305,7 +305,7 @@ void Application::openDownloads()
 
 QString Application::version() const
 {
-    return QString( "1.1.1" );
+    return QString( "1.1.2" );
 }
 
 QString Application::protocolVersion() const
@@ -518,6 +518,7 @@ void Application::initializeSettings()
         { "ConnectAtStartup", (int)RestoreNever },
         { "AutoStart", false },
         { "AutoUpdate", true },
+        { "TextSizeMultiplier", 100 },
         { "DefaultAttachmentAction", (int)ActionAsk },
         { "FolderUpdateInterval", 1 },
         { "UpdateInterval", 5 },
@@ -570,7 +571,7 @@ void Application::restoreState()
 
 double Application::textSizeMultiplier() const
 {
-    return QFontMetrics( m_editorFont ).height() / 13.0;
+    return QFontMetrics( m_editorFont ).height() * m_settings->value( "TextSizeMultiplier" ).toInt() / 1300.0;
 }
 
 QPrinter* Application::printer()
