@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2013 WebIssues Team
+* Copyright (C) 2007-2014 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -201,6 +201,11 @@ public:
     */
     const QString& currentUserLogin() const { return m_currentUserLogin; }
 
+    /**
+    * Return the password of the current user.
+    */
+    const QString& currentUserPassword() const { return m_currentUserPassword; }
+
     /**
     * Return the name of the current user.
     */
@@ -474,6 +479,7 @@ private:
 
     int m_currentUserId;
     QString m_currentUserLogin;
+    QString m_currentUserPassword;
     QString m_currentUserName;
     Access m_currentUserAccess;
 
