@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2013 WebIssues Team
+* Copyright (C) 2007-2014 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,8 @@ public:
     */
     enum Unit
     {
+        /** Update user's global access. */
+        GlobalAccess,
         /** Update server settings. */
         Settings,
         /** Update users and their membership. */
