@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2014 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -60,6 +60,11 @@ public:
     */
     int issueId() const { return m_issueId; }
 
+    /**
+    * Execute the command if necessary and return the identifier of the issue.
+    */
+    static int getFindItem( QWidget* parent, int itemId );
+
 public: // overrides
     void accept();
 
