@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2013 WebIssues Team
+* Copyright (C) 2007-2014 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -54,6 +54,9 @@ SettingsDialog::SettingsDialog( QWidget* parent ) : CommandDialog( parent )
     for ( QMap<QString, QString>::iterator it = languages.begin(); it != languages.end(); it++ )
         m_ui.languageComboBox->addItem( it.value(), it.key() );
 
+    for ( int i = 100; i <= 150; i += 25 )
+        m_ui.textSizeComboBox->addItem( QString( "%1%" ).arg( i ), i );
+
 #if defined( Q_WS_WIN )
     if ( application->isPortableMode() )
         m_ui.autoStartCheckBox->hide();
@@ -75,14 +78,16 @@ SettingsDialog::SettingsDialog( QWidget* parent ) : CommandDialog( parent )
 
     LocalSettings* settings = application->applicationSettings();
 
-    int index = m_ui.languageComboBox->findData( settings->value( "Language" ).toString() );
-    if ( index >= 2 )
-        m_ui.languageComboBox->setCurrentIndex( index );
+    int index = m_ui.languageComboBox->findData( settings->value( "Language" ) );
+    m_ui.languageComboBox->setCurrentIndex( index >= 2 ? index : 0 );
 
     m_ui.dockCheckBox->setChecked( settings->value( "Docked" ).toBool() );
     m_ui.showComboBox->setCurrentIndex( settings->value( "ShowAtStartup" ).toInt() );
     m_ui.reconnectComboBox->setCurrentIndex( settings->value( "ConnectAtStartup" ).toInt() );
 
+    index = m_ui.textSizeComboBox->findData( settings->value( "TextSizeMultiplier" ) );
+    m_ui.textSizeComboBox->setCurrentIndex( index > 0 ? index : 0 );
+
 #if defined( Q_WS_WIN )
     if ( !application->isPortableMode() )
         m_ui.autoStartCheckBox->setChecked( settings->value( "AutoStart" ).toBool() );
@@ -135,6 +140,8 @@ bool SettingsDialog::apply()
     settings->setValue( "ShowAtStartup", m_ui.showComboBox->currentIndex() );
     settings->setValue( "ConnectAtStartup", m_ui.reconnectComboBox->currentIndex() );
 
+    settings->setValue( "TextSizeMultiplier", m_ui.textSizeComboBox->itemData( m_ui.textSizeComboBox->currentIndex() ) );
+
 #if defined( Q_WS_WIN )
     if ( !application->isPortableMode() )
         settings->setValue( "AutoStart", m_ui.autoStartCheckBox->isChecked() );
