@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2013 WebIssues Team
+* Copyright (C) 2007-2014 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -458,6 +458,8 @@ void MainWindow::connectionOpened()
     m_userLabel->setText( dataManager->currentUserName() );
     m_userLabel->show();
 
+    dataManager->addObserver( this );
+
     m_activeView = m_view;
 
     builder()->addClient( m_view );
@@ -506,6 +508,20 @@ void MainWindow::connectionOpened()
     m_view->mainWidget()->setFocus();
 }
 
+void MainWindow::customEvent( QEvent* e )
+{
+    if ( e->type() == UpdateEvent::Type ) {
+        UpdateEvent* ue = (UpdateEvent*)e;
+        if ( ue->unit() == UpdateEvent::GlobalAccess ) {
+            QPixmap userPixmap = ( dataManager->currentUserAccess() == AdminAccess ) ? IconLoader::overlayedPixmap( "user", "overlay-admin" ) : IconLoader::pixmap( "user" );
+            m_userLabel->setPixmap( userPixmap );
+            m_userLabel->setText( dataManager->currentUserName() );
+
+            updateActions( true );
+        }
+    }
+}
+
 void MainWindow::restoreViewState()
 {
     LocalSettings* settings = application->applicationSettings();
