@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2013 WebIssues Team
+* Copyright (C) 2007-2014 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -336,7 +336,10 @@ HtmlText IssueDetailsGenerator::formatFile( const FileEntity& file, HtmlText::Fl
 {
     HtmlText result( flags );
 
-    result.appendLink( file.name(), QString( "attachment://%1" ).arg( file.id() ) );
+    if ( !flags.testFlag( HtmlText::NoInternalLinks ) )
+        result.appendLink( file.name(), QString( "attachment://%1" ).arg( file.id() ) );
+    else
+        result.appendText( file.name() );
     result.appendText( " (" );
 
     Formatter formatter;
