@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2013 WebIssues Team
+* Copyright (C) 2007-2014 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -249,7 +249,7 @@ QString QueryGenerator::generateConditions()
 
     if ( !m_searchText.isEmpty() ) {
         DefinitionInfo info;
-        info.setType( "CON" );
+        info.setType( m_searchColumn == Column_ID ? "EQ" : "CON" );
         info.setMetadata( "column", m_searchColumn );
         info.setMetadata( "value", m_searchText );
         allFilters.append( info );
