@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2013 WebIssues Team
+* Copyright (C) 2007-2014 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -222,7 +222,8 @@ IssueView::IssueView( QObject* parent, QWidget* parentWidget ) : View( parent ),
     connect( m_browser, SIGNAL( customContextMenuRequested( const QPoint& ) ),
         this, SLOT( historyContextMenu( const QPoint& ) ) );
     connect( m_browser, SIGNAL( linkClicked( const QUrl& ) ), this, SLOT( linkClicked( const QUrl& ) ) );
-    connect( m_browser, SIGNAL( selectionChanged() ), this, SLOT( updateActions() ) );
+
+    connect( m_browser->pageAction( QWebPage::Copy ), SIGNAL( changed() ), this, SLOT( updateActions() ) );
 
     connect( m_browser->page()->mainFrame(), SIGNAL( loadFinished( bool ) ), this, SLOT( scrollToAnchor() ) );
 
@@ -249,6 +250,8 @@ IssueView::IssueView( QObject* parent, QWidget* parentWidget ) : View( parent ),
     m_populateTimer->setSingleShot( true );
 
     connect( m_populateTimer, SIGNAL( timeout() ), this, SLOT( populateDetails() ) );
+
+    connect( application->applicationSettings(), SIGNAL( settingsChanged() ), this, SLOT( settingsChanged() ) );
 }
 
 IssueView::~IssueView()
@@ -993,3 +996,8 @@ void IssueView::handleAttachment( int fileId, AttachmentAction action )
             MessageBox::warning( mainWidget(), tr( "Error" ), tr( "File could not be saved." ) );
     }
 }
+
+void IssueView::settingsChanged()
+{
+    m_browser->setTextSizeMultiplier( application->textSizeMultiplier() );
+}
