@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2013 WebIssues Team
+* Copyright (C) 2007-2014 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -257,7 +257,6 @@ void ListView::cleanUp()
         helper.saveColumnWidths( "FolderViewWidths", m_model->columns() );
     }
 
-    m_searchBox->clear();
     m_currentViewId = 0;
 
     delete m_model;
@@ -268,6 +267,8 @@ void ListView::initialUpdate()
 {
     cleanUp();
 
+    m_searchBox->clear();
+
     m_model = new FolderModel( this );
 
     connect( m_model, SIGNAL( layoutChanged() ), this, SLOT( updateActions() ) );
@@ -600,7 +601,7 @@ void ListView::updateSearchOptions()
 
     QList<int> columns;
     foreach ( int column, allColumns ) {
-        if ( cache->availableOperators( column ).contains( "CON" ) )
+        if ( column == Column_ID || cache->availableOperators( column ).contains( "CON" ) )
             columns.append( column );
     }
 
@@ -629,7 +630,8 @@ void ListView::updateSearchOptions()
 
 void ListView::quickSearchChanged( const QString& text )
 {
-    m_model->setSearchText( m_searchColumn, text );
+    if ( m_model )
+        m_model->setSearchText( m_searchColumn, text );
 }
 
 void ListView::searchActionTriggered( QAction* action )
