@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2013 WebIssues Team
+* Copyright (C) 2007-2014 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -159,7 +159,8 @@ SummaryView::SummaryView( QObject* parent, QWidget* parentWidget ) : View( paren
     connect( m_browser, SIGNAL( customContextMenuRequested( const QPoint& ) ),
         this, SLOT( summaryContextMenu( const QPoint& ) ) );
     connect( m_browser, SIGNAL( linkClicked( const QUrl& ) ), this, SLOT( linkClicked( const QUrl& ) ) );
-    connect( m_browser, SIGNAL( selectionChanged() ), this, SLOT( updateActions() ) );
+
+    connect( m_browser->pageAction( QWebPage::Copy ), SIGNAL( changed() ), this, SLOT( updateActions() ) );
 
     m_findBar = new FindBar( main );
     m_findBar->setBoundWidget( m_browser );
@@ -184,6 +185,8 @@ SummaryView::SummaryView( QObject* parent, QWidget* parentWidget ) : View( paren
     m_populateTimer->setSingleShot( true );
 
     connect( m_populateTimer, SIGNAL( timeout() ), this, SLOT( populateSummary() ) );
+
+    connect( application->applicationSettings(), SIGNAL( settingsChanged() ), this, SLOT( settingsChanged() ) );
 }
 
 SummaryView::~SummaryView()
@@ -564,3 +567,8 @@ void SummaryView::findItem( int itemId )
     else
         emit issueActivated( issueId, itemId );
 }
+
+void SummaryView::settingsChanged()
+{
+    m_browser->setTextSizeMultiplier( application->textSizeMultiplier() );
+}
